@@ -756,19 +756,18 @@ const LocalDocument = new Lang.Class({
             return;
 
         let file = Gio.file_new_for_uri(this.uri);
-        file.delete_async(GLib.PRIORITY_DEFAULT, null, Lang.bind(this,
+        file.trash_async(GLib.PRIORITY_DEFAULT, null, Lang.bind(this,
             function(source, res) {
                 try {
-                    file.delete_finish(res);
+                    file.trash_finish(res);
                 } catch(e) {
-                    log('Unable to delete ' + this.uri + ': ' + e.message);
+                    log('Unable to trash ' + this.uri + ': ' + e.message);
                 }
             }));
     }
 });
 
-const _GOOGLE_DOCS_SCHEME_LABELS = "http://schemas.google.com/g/2005/labels";
-const _GOOGLE_DOCS_TERM_STARRED = "http://schemas.google.com/g/2005/labels#starred";
+const GOOGLE_PREFIX = 'google:drive:';
 
 const GoogleDocument = new Lang.Class({
     Name: 'GoogleDocument',
@@ -784,15 +783,16 @@ const GoogleDocument = new Lang.Class({
         this.sourceName = _("Google");
     },
 
-    _createGDataEntry: function(cancellable, callback) {
+    createGDataEntry: function(cancellable, callback) {
         let source = Application.sourceManager.getItemById(this.resourceUrn);
 
         let authorizer = new GData.GoaAuthorizer({ goa_object: source.object });
         let service = new GData.DocumentsService({ authorizer: authorizer });
+        let gdata_id = this.identifier.substring(GOOGLE_PREFIX.length);
 
         service.query_single_entry_async
             (GData.DocumentsService.get_primary_authorization_domain(),
-             this.identifier, null,
+             gdata_id, null,
              GData.DocumentsText,
              cancellable, Lang.bind(this,
                  function(object, res) {
@@ -810,7 +810,7 @@ const GoogleDocument = new Lang.Class({
     },
 
     load: function(passwd, cancellable, callback) {
-        this._createGDataEntry(cancellable, Lang.bind(this,
+        this.createGDataEntry(cancellable, Lang.bind(this,
             function(entry, service, exception) {
                 if (exception) {
                     // try loading from the most recent cache, if any
@@ -842,7 +842,7 @@ const GoogleDocument = new Lang.Class({
     },
 
     createThumbnail: function(callback) {
-        this._createGDataEntry(null, Lang.bind(this,
+        this.createGDataEntry(null, Lang.bind(this,
             function(entry, service, exception) {
                 if (exception) {
                     callback(false);
@@ -1155,7 +1155,7 @@ const DocumentManager = new Lang.Class({
 
     _identifierIsGoogle: function(identifier) {
         return (identifier &&
-                (identifier.indexOf('https://docs.google.com') != -1));
+                (identifier.indexOf(GOOGLE_PREFIX) != -1));
     },
 
     _identifierIsOwncloud: function(identifier) {
