@@ -23,6 +23,7 @@ const Cairo = imports.gi.cairo;
 const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
 const Gettext = imports.gettext;
+const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
@@ -344,12 +345,12 @@ const ViewContainer = new Lang.Class({
                             Lang.bind(this, this._onViewSelectionChanged));
 
         // connect to settings change for list/grid view
-        this._viewSettingsId = Application.application.connect('action-state-changed::view-as',
+        let viewSettingsId = Application.application.connect('action-state-changed::view-as',
             Lang.bind(this, this._updateTypeForSettings));
         this._updateTypeForSettings();
 
         // setup selection controller => view
-        this._selectionModeId = Application.selectionController.connect('selection-mode-changed',
+        Application.selectionController.connect('selection-mode-changed',
             Lang.bind(this, this._onSelectionModeChanged));
         this._onSelectionModeChanged();
 
@@ -358,13 +359,13 @@ const ViewContainer = new Lang.Class({
         this._onWindowModeChanged();
 
         let selectAll = Application.application.lookup_action('select-all');
-        selectAll.connect('activate', Lang.bind(this,
+        let selectAllId = selectAll.connect('activate', Lang.bind(this,
             function() {
                 this.view.select_all();
             }));
 
         let selectNone = Application.application.lookup_action('select-none');
-        selectNone.connect('activate', Lang.bind(this,
+        let selectNoneId = selectNone.connect('activate', Lang.bind(this,
             function() {
                 this.view.unselect_all();
             }));
@@ -381,13 +382,20 @@ const ViewContainer = new Lang.Class({
 
         this._trackerController.connect('query-error',
             Lang.bind(this, this._onQueryError));
-        this._queryId = this._trackerController.connect('query-status-changed',
+        this._trackerController.connect('query-status-changed',
             Lang.bind(this, this._onQueryStatusChanged));
         // ensure the tracker controller is started
         this._trackerController.start();
 
         // this will create the model if we're done querying
         this._onQueryStatusChanged();
+
+        this.widget.connect('destroy', Lang.bind(this,
+            function() {
+                Application.application.disconnect(viewSettingsId);
+                selectAll.disconnect(selectAllId);
+                selectNone.disconnect(selectNoneId);
+            }));
     },
 
     _updateTypeForSettings: function() {
